.. tsinfer documentation master file, created by
   sphinx-quickstart on Fri May 11 10:54:43 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tsinfer's documentation!
===================================

This is the documentation for ``tsinfer``, a method for inferring correlated
genealogies (a.k.a. tree sequence or ARGs) from genetic variation data.

Contents:
=========

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   installation
   tutorial
   inference
   api
   cli
   file_formats
   development


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
